@@ -92,7 +92,8 @@ def _run_envchain_command(
         A tuple (stdout_str, stderr_str).
 
     Raises:
-        EnvchainError: If envchain is not found or the command returns a non-zero exit code.
+        EnvchainError: If envchain is not found or the command returns a non-zero exit code,
+                      or if stderr indicates a namespace is not defined.
     """
     logger.debug(f"Executing envchain command: {' '.join(cmd_list)}")
     if input_payload_str is not None:
@@ -342,6 +343,61 @@ def list_namespaces() -> list[str]:
     return namespaces
 
 
+def delete_namespace(namespace: str) -> None:
+    """
+    Deletes an envchain namespace by unsetting all keys in it.
+
+    Args:
+        namespace: The envchain namespace to delete.
+
+    Raises:
+        ValueError: If namespace is empty.
+        TypeError: If arguments have incorrect types.
+        EnvchainError: If the envchain command fails (e.g., namespace not found).
+    """
+    if not isinstance(namespace, str) or not namespace.strip():
+        raise ValueError("Namespace must be a non-empty string.")
+    namespace = namespace.strip()
+
+    # Get keys via list_keys_in_namespace, which now raises for nonexistent
+    keys = list_keys_in_namespace(namespace)
+    if not keys:
+        raise EnvchainError(
+            f"Namespace '{namespace}' is empty. Cannot delete an empty namespace."
+        )
+    unset_vars(namespace, keys)
+    logger.info(f"Successfully deleted all keys from namespace '{namespace}'.")
+
+
+def list_keys_in_namespace(namespace: str) -> list[str]:
+    """
+    Lists all keys in the specified envchain namespace.
+
+    Args:
+        namespace: The envchain namespace.
+    Returns:
+        A list of variable keys (strings) in the namespace.
+        Returns an empty list if the namespace is valid but has no variables.
+    Raises:
+        ValueError: If namespace is empty.
+        TypeError: If arguments have incorrect types.
+        EnvchainError: If the envchain command fails (e.g., namespace not found).
+    """
+    if not isinstance(namespace, str) or not namespace.strip():
+        raise ValueError("Namespace must be a non-empty string.")
+    namespace = namespace.strip()
+
+    envchain_cmd_list = ["envchain", "--list", namespace]
+    logger.info(f"Listing keys in envchain namespace '{namespace}'.")
+
+    stdout, stderr = _run_envchain_command(envchain_cmd_list)
+    # Raise if stderr indicates namespace not defined
+    if stderr and "not defined" in stderr.lower():
+        raise EnvchainError(f"Namespace '{namespace}' does not exist.")
+    keys = [line.strip() for line in stdout.splitlines() if line.strip()]
+    return keys
+
+
 def get_vars(namespace: str, *variable_keys: str) -> dict[str, str]:
     """
     Retrieves specified variables from an envchain namespace.
@@ -380,8 +436,13 @@ def get_vars(namespace: str, *variable_keys: str) -> dict[str, str]:
     if keys_to_filter:
         logger.debug(f"Filtering for keys: {', '.join(keys_to_filter)}")
 
-    # This command might fail with EnvchainError if namespace doesn't exist (return code 1)
-    stdout, stderr = _run_envchain_command(envchain_cmd_list)
+    try:
+        stdout, stderr = _run_envchain_command(envchain_cmd_list)
+    except EnvchainError as e:
+        # If namespace does not exist, treat as empty
+        if e.stderr and "not defined" in e.stderr.lower():
+            return {}
+        raise
 
     if stderr:  # Even on success, there might be warnings (e.g. on Linux about --require-passphrase if it were applicable here)
         logger.warning(f"envchain stderr (get_vars):\n{stderr}")
